abacusai.application_connector — AbacusAI documentation

# `abacusai.application_connector`

## Module Contents

### Classes

`ApplicationConnector` | A connector to an external service

class abacusai.application_connector.ApplicationConnector(client, applicationConnectorId=None, service=None, name=None, createdAt=None, status=None, auth=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A connector to an external service

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - applicationConnectorId (str) – The unique ID for the connection.

    - service (str) – The service this connection connects to

    - name (str) – A user-friendly name for the service

    - createdAt (str) – When the API key was created

    - status (str) – The status of the Application Connector

    - auth (dict) – Non-secret connection information for this connector

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict

  create_feature_group_from_git(branch_name, table_name, function_name, module_name, python_root=None, input_feature_groups=None, description=None, cpu_size=None, memory=None, package_requirements=None)

    Creates a new feature group from a ZIP file.

    Parameters

      - branch_name (str) – Name of the branch in the git repository to be used for training.

      - table_name (str) – The unique name to be given to the feature group.

      - function_name (str) – Name of the function found in the module that will be executed (on the optional inputs) to materialize this feature group.

      - module_name (str) – Path to the file with the feature group function.

      - python_root (str) – Path from the top level of the git repository to the directory containing the Python source code. If not provided, the default is the root of the git repository.

      - input_feature_groups (list) – List of feature groups that are supplied to the function as parameters. Each of the parameters are materialized Dataframes (same type as the functions return value).

      - description (str) – The description about the feature group.

      - cpu_size (str) – Size of the cpu for the feature group function

      - memory (int) – Memory (in GB) for the feature group function

      - package_requirements (dict) – Json with key value pairs corresponding to package: version for each dependency

    Returns

      The created feature group

    Return type

      FeatureGroup

  rename(name)

    Renames an Application Connector

    Parameters

      name (str) – A new name for the application connector

  delete()

    Delete a application connector.

    Parameters

      application_connector_id (str) – The unique identifier for the application connector.

  list_objects()

    Lists querable objects in the application connector.

    Parameters

      application_connector_id (str) – The unique identifier for the application connector.

  verify()

    Checks to see if Abacus.AI can access the Application.

    Parameters

      application_connector_id (str) – The unique identifier for the application connector.